@@ -1,3 +1,5 @@
+from datetime import datetime
+
 from pydantic import BaseModel
 
 __all__ = ["Creator"]
@@ -10,11 +12,11 @@ class Creator(BaseModel):
     """The number of times this creator has been favorited"""
     id: str
     """The ID of the creator"""
-    indexed: float
+    indexed: datetime
     """Timestamp when the creator was indexed, Unix time as integer"""
     name: str
     """The name of the creator"""
     service: str
     """The service for the creator"""
-    updated: float
+    updated: datetime
     """Timestamp when the creator was last updated, Unix time as integer"""
