@@ -1,5 +1,6 @@
-from typing import List
+from typing import List, TypeVar
 
+import httpx
 from pydantic import RootModel
 
 from ktoolbox.api import BaseAPI, APIRet
@@ -7,9 +8,11 @@ from ktoolbox.api.model import Post
 
 __all__ = ["GetCreatorPost", "get_creator_post"]
 
+_T = TypeVar('_T')
+
 
 class GetCreatorPost(BaseAPI):
-    path = "/{service}/user/{creator_id}"
+    path = "/{service}/user/{creator_id}/posts"
     method = "get"
 
     class Response(RootModel[List[Post]]):
@@ -33,5 +36,9 @@ class GetCreatorPost(BaseAPI):
             }
         )
 
+    @classmethod
+    def handle_res(cls, res: httpx.Response) -> APIRet[_T]:
+        return APIRet(data=[]) if res.status_code == 404 else super().handle_res(res)
+
 
 get_creator_post = GetCreatorPost.__call__
